// Copyright 2020, OpenTelemetry Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package simpleprometheusreceiver

import (
	"context"
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"go.opentelemetry.io/collector/component"
	"go.opentelemetry.io/collector/config/configerror"
	"go.opentelemetry.io/collector/config/configmodels"
	"go.opentelemetry.io/collector/testbed/testbed"
	"go.uber.org/zap"
)

func TestFactory(t *testing.T) {
	f := &Factory{}
	assert.Equal(t, configmodels.Type("prometheus_simple"), f.Type())

	cfg := f.CreateDefaultConfig()
	require.NotNil(t, cfg)

	r, err := f.CreateMetricsReceiver(
		context.Background(),
		component.ReceiverCreateParams{Logger: zap.NewNop()},
		cfg,
		&testbed.MockMetricConsumer{},
	)
	require.NoError(t, err)
	require.NotNil(t, r)

	_, err = f.CreateTraceReceiver(
		context.Background(),
		component.ReceiverCreateParams{Logger: zap.NewNop()},
		cfg,
		&testbed.MockTraceConsumer{},
	)
	require.Equal(t, configerror.ErrDataTypeIsNotSupported, err)
}
